@@ -253,26 +253,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 static gboolean
 is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
 {
-  WebKitDOMHTMLElement *element;
-  gboolean ret;
-  gchar *id;
-
-  id = NULL;
-  ret = FALSE;
-
-  if (!WEBKIT_DOM_IS_HTML_BUTTON_ELEMENT (node))
-    goto out;
-
-  element = WEBKIT_DOM_HTML_ELEMENT (node);
-  id = webkit_dom_html_element_get_id (element);
-  if (g_strcmp0 (id, "submit_deny_access") != 0)
-    goto out;
-
-  ret = TRUE;
-
- out:
-  g_free (id);
-  return ret;
+  return FALSE;
 }
 
 static gboolean
@@ -428,6 +409,7 @@ build_object (GoaProvider         *provider,
                         "smtp-supported",  TRUE,
                         "smtp-host",       "smtp.gmail.com",
                         "smtp-user-name",  email_address,
+                        "smtp-use-auth",   TRUE,
                         "smtp-use-tls",    TRUE,
                         NULL);
           goa_object_skeleton_set_mail (object, mail);
